@@ -18,7 +18,7 @@ from .exceptions import (
     InvalidAuthError,
 )
 
-from .utils import get_info, get_status
+from .utils import get_info, get_status, restart
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -60,7 +60,7 @@ class Py2NDevice:
         finally:
             self._initializing = False
 
-    async def update(self) -> Py2NDeviceData:
+    async def update(self) -> None:
         ip = self.options.ip_address
 
         try:
@@ -75,16 +75,16 @@ class Py2NDevice:
                 hardware=self._info["hwVersion"],
                 uptime=datetime.now(timezone.utc) - timedelta(seconds=self._status["upTime"])
             )
-        except InvalidAuthError as err:
+        except Py2NError as err:
             self._last_error = err
-            _LOGGER.debug("host %s: error: %r", ip, self._last_error)
             raise
-        except CONNECT_ERRORS as err:
-            self._last_error = DeviceConnectionError(err)
-            _LOGGER.debug("host %s: error: %r", ip, self._last_error)
-            raise DeviceConnectionError(err) from err
 
-        return self._data
+    async def restart(self) -> None:
+        try:
+            await restart(self.aiohttp_session, self.options)
+        except Py2NError as err:
+            self._last_error = err
+            raise
 
     @property
     def ip_address(self) -> str:
